@@ -12,8 +12,9 @@ import pytest
 from aiohttp.web_request import Request
 from aiohttp.web_response import Response
 
-from bantam.decorators import web_api, RestMethod, AsyncLineIterator
-from bantam.web import WebApplication
+from bantam.decorators import web_api
+from bantam.api import AsyncLineIterator, RestMethod
+from bantam.http import WebApplication
 
 
 class RestAPIExample:
@@ -151,28 +152,33 @@ class TestJavascriptGenerator:
         async def launch_browser():
             await asyncio.sleep(2.0)
             browser = None
+            default = False
             try:
                 browser = webbrowser.get("chrome")
             except:
                 with suppress(Exception):
                     browser = webbrowser.get("google-chrome")
-            flags = ["--new-window"] if browser else []
+                if not browser:
+                    browser = webbrowser.get()
+                    default = True
+            flags = ["--new-window"] if browser and not default else []
             if not browser:
                 with suppress(Exception):
                     browser = webbrowser.get("firefox")
                     flags = ["-new-instance"]
             if not browser:
                 os.write(sys.stderr.fileno(),
-                         b"UNABLE TO GET BROWSER SUPPORINT HEADLESS CONFIGURATION. DEFAULTING TO NON_HEADLESSS")
+                         b"UNABLE TO GET BROWSER SUPPORT HEADLESS CONFIGURATION. DEFAULTING TO NON_HEADLESSS")
                 browser = webbrowser.get()
-            cmdline = [browser.name] + flags + ["http://localhost:8080/static/index.html"]
-            process = subprocess.Popen(cmdline)
+            # cmdline = [browser.name] + flags + \
+            browser.open("http://localhost:8080/static/index.html")
+            # process = subprocess.Popen(cmdline)
             result = await RestAPIExample.result_queue.get()
             await asyncio.sleep(2.0)
             await app.shutdown()
-            if process.returncode != None:
-                raise Exception("Browser died!")
-            process.kill()
+            # if process.returncode != None:
+            #    raise Exception("Browser died!")
+            # process.kill()
             return result
 
         try:
